#!/bin/sh

# this script checks if /opt mounted

BN=$(basename $0)

# usage
print_usage ()
{
  echo "Usage: "
  echo " $BN"
  echo "    mount /opt (ro) only when /opt currently is not mounted"
  echo " $BN ro"
  echo "    mount /opt (ro) if /opt is not mounted, or remount it ro"
  echo " $BN rw"
  echo "    mount /opt (rw) if /opt is not mounted, or remount it rw"
  echo " $BN um"
  echo "    umount /opt"
  echo " $BN st"
  echo "    show /opt status"
  echo " $BN --help|-h|-?"
  echo "    print out usage"
}


if [ "a$1" = "a--help" -o "a$1" = "a-h" -o "a$1" = "a-?" ] ; then
  print_usage
  exit 0
fi

# check params
if [ -n "$1" -a \
	"$1" != "ro" -a \
	"$1" != "rw" -a \
	"$1" != "um" -a \
	"$1" != "st" ] ; then
	echo "$BN: unknown param [$1]!"
	echo " "
	print_usage
	exit 1
fi

# check if /opt is currently mounted
MOUNTED=""
MOUNTST="" 
CHKMOUNT=$(grep /dev/loop /etc/mtab | grep " /opt ") 
if [ -n "$CHKMOUNT" ] ; then
	MOUNTST=$(echo $CHKMOUNT | tr -s ' ' | cut -d ' ' -f 4)
	MOUNTED=${MOUNTST:0:2}
fi

if [ "$1" = "st" ] ; then
  if [ -n "$MOUNTED" ] ; then
    echo "$BN: /opt currently is mounted ($MOUNTED)"
  else
    echo "$BN: /opt currently is NOT mounted"
  fi
  exit 0
fi

if [ "a$1" = "a" ] ; then
  if [ -n "$MOUNTED" ] ; then
    echo "$BN: /opt currently is mounted ($MOUNTED)"
	exit 0
  fi
fi

if [ "$1" = "um" ] ; then
  if [ -z "$MOUNTED" ] ; then
    echo "$BN: /opt currently is NOT mounted"
	exit 0
  fi
fi

if [ -n "$MOUNTED" -a "$MOUNTED" = "$1" ] ; then
  echo "$BN: /opt currently is already mounted ($MOUNTED)"
  exit 0
fi

# at this point we must be superuser to continue
WHOAMI=$(whoami)
if [ "a$WHOAMI" = "aroot" ] ; then
	SUDOCMD=" "
else
	SUDOCMD="/usr/bin/sudo"
	$SUDOCMD -v -p "[sudo] password for $WHOAMI:"
	if [ $? -ne 0 ] ; then
	  echo "$BN: failed to verify password, quit."
	  exit 1
	fi
fi

if [ "$1" = "um" ] ; then
  $SUDOCMD umount /opt
	if [ $? -ne 0 ] ; then
	  echo "$BN: failed to umount /opt, quit."
	  exit 1
	fi
  exit 0
fi

# please, make these paths FIXED!
LXLLOCALFS="/home/lxl/personal/lxllocal/lxllocal.ext3fs"
LOGF="/tmp/lxl_chk_localopt.log"
$SUDOCMD rm -rf $LOGF

if [ -z "$MOUNTED" ] ; then
	XFST="ro"
	# /opt currently is NOT mounted
	if [ ! -f ${LXLLOCALFS} ] ; then
	  # harddisk does NOT have lxllocal fs image
	  echo "$BN: FS image is not ready."
	  echo "no fs image file found." > $LOGF
	  exit 1
	fi
	if [ -n "$1" ] ; then
		XFST="$1"
	fi
	MOUNTOP="loop,$XFST"
	$SUDOCMD mkdir -p /opt
	echo "$BN: mounting /opt ($XFST)..."
	echo "mounting /opt ($XFST)..." > $LOGF
	$SUDOCMD /bin/mount -t ext3 -o $MOUNTOP "$LXLLOCALFS" /opt
	if [ $? -ne 0 ] ; then
	  echo "$BN: failed to mount /opt, quit."
	  exit 1
	fi
	echo "$BN: /opt is mounted"
	exit 0
fi

# /opt currently is mounted, so re-mount
XFST="ro"
if [ -n "$1" ] ; then
	XFST="$1"
fi
MOUNTOP="remount,$XFST"
$SUDOCMD mkdir -p /opt
echo "$BN: re-mounting /opt ($XFST)..."
echo "re-mounting /opt ($XFST)..." > $LOGF
$SUDOCMD mount -o $MOUNTOP /opt
if [ $? -ne 0 ] ; then
  echo "$BN: failed to re-mount /opt, quit."
  exit 1
fi
echo "$BN: /opt is re-mounted"
exit 0

